@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gestures-extension.c 1652 2008-01-08 21:46:27Z wbolster $
+ *  $Id$
  */
 
 #include "config.h"
@@ -27,8 +27,7 @@
 #include "ephy-file-helpers.h"
 #include "ephy-debug.h"
 
-#include <epiphany/ephy-embed.h>
-#include <epiphany/ephy-extension.h>
+#include <epiphany/epiphany.h>
 
 #include <gmodule.h>
 #include <libxml/tree.h>
