@@ -15,7 +15,7 @@
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
-*  $Id: livehttpheaders-ui.c 1376 2006-09-13 19:01:42Z chpe $
+*  $Id$
 */
 
 #include "config.h"
@@ -26,8 +26,7 @@
 #include "ephy-gui.h"
 #include "ephy-debug.h"
 
-#include <epiphany/ephy-embed-single.h>
-#include <epiphany/ephy-shell.h>
+#include <epiphany/epiphany.h>
 
 #include <glib/gi18n-lib.h>
 #include <gtk/gtkdialog.h>
