@@ -18,7 +18,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id$
  */
 
 /* this file is based on work of Daniel Erat for galeon 1 */
@@ -68,6 +67,23 @@ ephy_push_scroller_set_window (EphyPushScroller *scroller,
 	priv->window = window;
 }
 
+static void
+ephy_push_scroller_scroll_pixels (EphyEmbed *embed, int scroll_x, int scroll_y)
+{
+	GtkAdjustment *adj;
+	gdouble value;
+
+	g_return_if_fail (GTK_IS_SCROLLED_WINDOW (embed));
+
+	adj = gtk_scrolled_window_get_hadjustment (GTK_SCROLLED_WINDOW (embed));
+	value = gtk_adjustment_get_value (adj);
+	gtk_adjustment_set_value (adj, value + scroll_x);
+
+	adj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (embed));
+	value = gtk_adjustment_get_value (adj);
+	gtk_adjustment_set_value (adj, value + scroll_y);
+}
+
 static gboolean
 ephy_push_scroller_motion_cb (GtkWidget *widget,
 			      GdkEventMotion *event,
@@ -88,7 +104,7 @@ ephy_push_scroller_motion_cb (GtkWidget *widget,
 	y_dist_abs = abs (y_dist);
 
 	/* scroll */
-	ephy_embed_scroll_pixels (priv->embed, x_dist, y_dist);
+	ephy_push_scroller_scroll_pixels (priv->embed, x_dist, y_dist);
 
 	priv->start_x = event->x_root;
 	priv->start_y = event->y_root;
@@ -198,7 +214,7 @@ ephy_push_scroller_start (EphyPushScroller *scroller,
 	priv->start_y = y;
 
 	g_signal_connect (priv->window, "motion-notify-event",
-			    G_CALLBACK (ephy_push_scroller_motion_cb), scroller);
+			  G_CALLBACK (ephy_push_scroller_motion_cb), scroller);
 	g_signal_connect (priv->window, "button-press-event",
 			  G_CALLBACK (ephy_push_scroller_mouse_press_cb), scroller);
 	g_signal_connect (priv->window, "button-release-event",
